diff -u -r nginx-1.4.3.orig/src/http/modules/ngx_http_uwsgi_module.c nginx-1.4.3/src/http/modules/ngx_http_uwsgi_module.c
--- nginx-1.4.3.orig/src/http/modules/ngx_http_uwsgi_module.c	2013-10-08 14:07:14.000000000 +0200
+++ nginx-1.4.3/src/http/modules/ngx_http_uwsgi_module.c	2013-11-17 08:25:25.947189496 +0100
@@ -34,6 +34,10 @@
 
     ngx_uint_t                 modifier1;
     ngx_uint_t                 modifier2;
+
+#if (NGX_HTTP_SSL)
+    ngx_flag_t                 ssl;
+#endif
 } ngx_http_uwsgi_loc_conf_t;
 
 
@@ -65,6 +69,10 @@
 static char *ngx_http_uwsgi_cache_key(ngx_conf_t *cf, ngx_command_t *cmd,
     void *conf);
 #endif
+#if (NGX_HTTP_SSL)
+static ngx_int_t ngx_http_uwsgi_set_ssl(ngx_conf_t *cf,
+    ngx_http_uwsgi_loc_conf_t *uwcf);
+#endif
 
 
 static ngx_conf_num_bounds_t  ngx_http_uwsgi_modifier_bounds = {
@@ -353,6 +361,24 @@
       offsetof(ngx_http_uwsgi_loc_conf_t, upstream.ignore_headers),
       &ngx_http_upstream_ignore_headers_masks },
 
+#if (NGX_HTTP_SSL)
+
+    { ngx_string("uwsgi_ssl"),
+      NGX_HTTP_MAIN_CONF|NGX_HTTP_SRV_CONF|NGX_HTTP_LOC_CONF|NGX_CONF_FLAG,
+      ngx_conf_set_flag_slot,
+      NGX_HTTP_LOC_CONF_OFFSET,
+      offsetof(ngx_http_uwsgi_loc_conf_t, ssl),
+      NULL },
+
+    { ngx_string("uwsgi_ssl_session_reuse"),
+      NGX_HTTP_MAIN_CONF|NGX_HTTP_SRV_CONF|NGX_HTTP_LOC_CONF|NGX_CONF_FLAG,
+      ngx_conf_set_flag_slot,
+      NGX_HTTP_LOC_CONF_OFFSET,
+      offsetof(ngx_http_uwsgi_loc_conf_t, upstream.ssl_session_reuse),
+      NULL },
+
+#endif
+
       ngx_null_command
 };
 
@@ -455,6 +481,10 @@
     u = r->upstream;
 
     ngx_str_set(&u->schema, "uwsgi://");
+#if (NGX_HTTP_SSL)
+    u->ssl = (uwcf->upstream.ssl != NULL);
+#endif
+
     u->output.tag = (ngx_buf_tag_t) &ngx_http_uwsgi_module;
 
     u->conf = &uwcf->upstream;
@@ -1142,6 +1172,10 @@
     conf->upstream.pass_headers = NGX_CONF_UNSET_PTR;
 
     conf->upstream.intercept_errors = NGX_CONF_UNSET;
+#if (NGX_HTTP_SSL)
+    conf->upstream.ssl_session_reuse = NGX_CONF_UNSET;
+    conf->ssl = NGX_CONF_UNSET;
+#endif
 
     /* "uwsgi_cyclic_temp_file" is disabled */
     conf->upstream.cyclic_temp_file = 0;
@@ -1386,6 +1420,13 @@
     ngx_conf_merge_value(conf->upstream.intercept_errors,
                          prev->upstream.intercept_errors, 0);
 
+#if (NGX_HTTP_SSL)
+    ngx_conf_merge_value(conf->upstream.ssl_session_reuse,
+                              prev->upstream.ssl_session_reuse, 1);
+    ngx_conf_merge_value(conf->ssl,
+                              prev->ssl, 0);
+#endif
+
     ngx_conf_merge_str_value(conf->uwsgi_string, prev->uwsgi_string, "");
 
     hash.max_size = 512;
@@ -1645,6 +1686,12 @@
 
     *code = (uintptr_t) NULL;
 
+#if (NGX_HTTP_SSL)
+    if (conf->upstream.ssl == NULL) {
+        conf->upstream.ssl = prev->upstream.ssl;
+    }
+#endif
+
     conf->header_params = headers_names.nelts;
 
     hash.hash = &conf->headers_hash;
@@ -1699,9 +1746,25 @@
             return NGX_CONF_ERROR;
         }
 
+#if (NGX_HTTP_SSL)
+        if (uwcf->ssl == 1) {
+            if (ngx_http_uwsgi_set_ssl(cf, uwcf) != NGX_OK) {
+                return NGX_CONF_ERROR;
+            }
+        }
+#endif
+
         return NGX_CONF_OK;
     }
 
+#if (NGX_HTTP_SSL)
+    if (uwcf->ssl == 1) {
+        if (ngx_http_uwsgi_set_ssl(cf, uwcf) != NGX_OK) {
+            return NGX_CONF_ERROR;
+        }
+    }
+#endif
+
     ngx_memzero(&u, sizeof(ngx_url_t));
 
     u.url = value[1];
@@ -1838,3 +1901,40 @@
 }
 
 #endif
+
+#if (NGX_HTTP_SSL)
+
+static ngx_int_t
+ngx_http_uwsgi_set_ssl(ngx_conf_t *cf, ngx_http_uwsgi_loc_conf_t *uwcf)
+{
+    ngx_pool_cleanup_t  *cln;
+
+    uwcf->upstream.ssl = ngx_pcalloc(cf->pool, sizeof(ngx_ssl_t));
+    if (uwcf->upstream.ssl == NULL) {
+        return NGX_ERROR;
+    }
+
+    uwcf->upstream.ssl->log = cf->log;
+
+    if (ngx_ssl_create(uwcf->upstream.ssl,
+                       NGX_SSL_SSLv2|NGX_SSL_SSLv3|NGX_SSL_TLSv1
+                                    |NGX_SSL_TLSv1_1|NGX_SSL_TLSv1_2,
+                       NULL)
+        != NGX_OK)
+    {
+        return NGX_ERROR;
+    }
+
+    cln = ngx_pool_cleanup_add(cf->pool, 0);
+    if (cln == NULL) {
+        return NGX_ERROR;
+    }
+
+    cln->handler = ngx_ssl_cleanup_ctx;
+    cln->data = uwcf->upstream.ssl;
+
+    return NGX_OK;
+}
+
+#endif
+
